@@ -29,7 +29,7 @@ if not valid_version:  # pragma: no cover
     sys.exit()
 
 del valid_version
-__version__ = "0.4.36"
+__version__ = "0.5.0"
 
 
 # ===========================================
@@ -46,6 +46,7 @@ from friendly_traceback import explain_traceback as ft_explain_traceback
 from friendly_traceback import install as ft_install
 from friendly_traceback import set_formatter as ft_set_formatter
 from friendly_traceback import set_lang as ft_set_lang
+from friendly_traceback import __version__ as ft_version
 from friendly_traceback.config import session
 
 # The following are not used here, and simply made available directly for convenience
@@ -58,7 +59,7 @@ from friendly_traceback import (  # noqa
 )
 
 from .my_gettext import current_lang
-from friendly import rich_formatters, theme, configuration
+from friendly import rich_formatters, theme, settings
 
 
 exclude_directory_from_traceback(os.path.dirname(__file__))
@@ -202,10 +203,40 @@ def set_formatter(
     """Sets the default formatter. If no argument is given, a default
     formatter is used.
     """
+    if formatter is not None:
+        settings.write(option="formatter", value=formatter)
+        if background is not None:
+            settings.write(option="background", value=background)
+        else:
+            old_background = settings.read(option="background")
+            if (
+                formatter == settings.read(option="formatter")
+                and old_background is not None
+            ):
+                background = old_background
+    elif background is not None:
+        settings.write(option="background", value=background)
+        old_formatter = settings.read(option="formatter")
+        if old_formatter is not None:
+            formatter = old_formatter
+            old_color_system = settings.read(option="color_system")
+            if old_color_system is not None:
+                color_system = old_color_system
+            old_force_jupyter = settings.read(option="force_jupyter")
+            if old_force_jupyter is not None:
+                force_jupyter = old_force_jupyter
+        else:
+            return
+    if color_system is not None:
+        settings.write(option="color_system", value=color_system)
+    if force_jupyter is not None:
+        settings.write(option="force_jupyter", value=force_jupyter)
+
     session.rich_add_vspace = True
     session.use_rich = True
     session.jupyter_button_style = ""
-    configuration.write(key="formatter", value=formatter)
+    set_stream()
+    settings.write(option="formatter", value=formatter)
     if formatter in ["dark", "light"]:
         session.console = theme.init_rich_console(
             style=formatter,
@@ -224,7 +255,6 @@ def set_formatter(
         )
         formatter = rich_formatters.jupyter_interactive
         session.jupyter_button_style = ";color: white; background-color:black;"
-        set_stream()
     elif formatter in ["interactive", "interactive-light"]:
         session.console = theme.init_rich_console(
             style="light",
@@ -233,7 +263,10 @@ def set_formatter(
             background=background,
         )
         formatter = rich_formatters.jupyter_interactive
-        set_stream()
+    elif formatter == "jupyter":
+        formatter = rich_formatters.jupyter
+        session.use_rich = False
+        theme.disable_rich()
     else:
         session.use_rich = False
         set_stream()
@@ -271,13 +304,20 @@ def start_console(  # pragma: no cover
 def set_lang(lang):
     """Sets the language to be used."""
     ft_set_lang(lang)
-    configuration.write(key="lang", value=lang, environment="common")
+    settings.write(option="lang", value=lang, environment="common")
     current_lang.install(lang)
 
 
 set_lang(get_lang())
 
 
-def view_saved():
+def _print_settings():
     """View all saved values"""
-    configuration.view_saved()
\ No newline at end of file
+    settings.print_settings()
+
+
+def print_repl_header():
+    """Prints the header at the beginning of an interactive session."""
+    _ = current_lang.translate
+    print(f"friendly_traceback {ft_version}; friendly {__version__}.")
+    print(_("Type 'Friendly' for basic help."))
