@@ -21,9 +21,7 @@ from friendly_traceback import __version__ as ft_version
 from friendly_traceback import debug_helper
 
 from friendly import console, __version__
-from friendly import configuration
 from .my_gettext import current_lang
-configuration.ENVIRONMENT = "terminal"
 
 from friendly.rich_console_helpers import set_formatter
 
@@ -167,11 +165,6 @@ def main():
             set_formatter(formatter, background=args.background)  # pragma: no cover
         else:
             set_formatter(import_function(args.formatter))
-    else:
-        formatter = configuration.read(key="formatter")
-        if formatter is None:
-            formatter = "dark"
-        set_formatter(formatter, background=args.background)
 
     console_defaults = {}
     if args.source is not None:
