@@ -217,14 +217,21 @@ def start_console(
 ):
     """Starts a console; modified from code.interact"""
 
+    if friendly.settings.terminal_type:
+        friendly.settings.ENVIRONMENT = friendly.settings.terminal_type
+    else:
+        friendly.settings.ENVIRONMENT = "terminal"
+
     if lang is None:
         lang = friendly.get_lang()
     if banner is None:
         banner = BANNER + ft.ft_console.type_friendly() + "\n"
     if formatter is None:
-        formatter = friendly.configuration.read(key="formatter")
+        formatter = friendly.settings.read(option="formatter")
         if formatter is None:
             formatter = "dark"
+    if background is None:
+        background = friendly.settings.read(option="background")
 
     friendly.set_lang(lang)
 
