@@ -1,17 +1,19 @@
 """Mu's repl uses an IPython QtConsole.
 Mu has three themes designated (in English) as 'day', 'night',
 and 'high contrast'."""
-import sys
 
 import colorama  # noqa
 from friendly_traceback import set_stream
 from friendly_traceback import set_formatter as ft_set_formatter
-from friendly_traceback.config import session  # noqa
+from friendly_traceback.config import session, did_exception_occur_before  # noqa
 from friendly_traceback.functions_help import add_help_attribute, short_description
 
 from ..my_gettext import current_lang  # noqa
-from friendly.ipython import *  # noqa  # Will automatically install
+from friendly.ipython_common import excepthook
+from friendly.rich_console_helpers import *  # noqa
 from friendly.rich_console_helpers import Friendly, helpers
+from friendly import print_repl_header
+from friendly import settings
 from friendly import theme
 from friendly import rich_formatters
 
@@ -19,11 +21,16 @@ colorama.deinit()  # reset needed on Windows
 colorama.init(convert=False, strip=False)
 _ = current_lang.translate
 
+settings.ENVIRONMENT = "mu"
+
 
 def set_formatter(formatter=None, background=None):
     """Sets the default formatter. If no argument is given, a default
     formatter is used.
     """
+    settings.write(option="formatter", value=formatter)
+    if background is not None:
+        settings.write(option="background", value=background)
     if formatter in ["black", "day", "night"]:
         style = "light" if formatter == "day" else "dark"
         session.console = theme.init_rich_console(
@@ -102,10 +109,16 @@ for helper in local_helpers:
     Friendly.add_helper(local_helpers[helper])
 helpers.update(local_helpers)
 __all__ = list(helpers.keys())
-day()
 
-if session.exception_before_import:
-    if session.saved_info:
-        session.saved_info.pop()
-    session.get_traceback_info(sys.last_type, sys.last_value, sys.last_traceback)
+
+excepthook.install_except_hook()
+if settings.has_environment("mu"):
+    formatter = settings.read(option="formatter")
+    background = settings.read(option="background")
+    set_formatter(formatter=formatter, background=background)
+else:
+    day()
+
+print_repl_header()
+if did_exception_occur_before():
     friendly_tb()  # noqa
