@@ -9,7 +9,8 @@ from friendly_traceback.config import session
 old_set_lang = set_lang  # noqa
 
 from friendly.my_gettext import current_lang
-from friendly import set_lang, view_saved
+from friendly import set_lang, _print_settings
+from friendly.settings import _remove_environment
 
 # The following is different from the one imported via the import * above
 from friendly import set_formatter
@@ -62,12 +63,16 @@ def plain():
     set_formatter("plain")
 
 
+def set_background(color):
+    """Sets the background color for the current environment."""
+    set_formatter(background=color)
+
+
 def set_width(width=80):
-    """Sets the width in a iPython/Jupyter session using 'light' or 'dark' mode"""
+    """Sets the width in a iPython/Jupyter session using a Rich formatter."""
     try:
         session.console.width = width
     except Exception:  # noqa
-        print(_("set_width() has no effect with this formatter."))
         return
     session.rich_width = width
     if session.is_jupyter:
@@ -85,9 +90,21 @@ short_description["light"] = lambda: _(
     "Sets a colour scheme designed for a white background."
 )
 short_description["plain"] = lambda: _("Plain formatting, with no colours added.")
+short_description["set_background"] = lambda: _("Sets the background color.")
 short_description["set_width"] = lambda: _("Sets the output width in some modes.")
-short_description["view_saved"] = lambda : _("Prints the saved configuration.")
-local_helpers = {"dark": dark, "light": light, "plain": plain, "set_width": set_width, "view_saved": view_saved}
+short_description["_print_settings"] = lambda: _("Prints the saved settings.")
+short_description["_remove_environment"] = lambda: (
+    "Deletes an environment from the saved settings; default: current environment."
+)
+local_helpers = {
+    "dark": dark,
+    "light": light,
+    "plain": plain,
+    "set_width": set_width,
+    "set_background": set_background,
+    "_print_settings": _print_settings,
+    "_remove_environment": _remove_environment,
+}
 add_help_attribute(local_helpers)
 for helper in local_helpers:
     Friendly.add_helper(local_helpers[helper])
